Change Log
##########

..
   All enhancements and patches to persona_integration will be documented
   in this file.  It adheres to the structure of https://keepachangelog.com/ ,
   but in reStructuredText instead of Markdown (for ease of incorporation into
   Sphinx documentation and the PyPI description).

   This project adheres to Semantic Versioning (https://semver.org/).

.. There should always be an "Unreleased" section for changes pending release.

Unreleased
**********

2.0.2 - 2024-09-27
******************

Added
=====
* Add __init__.py to signals package.

2.0.1 - 2024-09-26
******************

Added
=====
* Add user persona account model and admin.
* Add VerificationAttempt model and admin to store Persona attempts.
* Add a view to handle Persona webhooks.
* Add a create inquiry view.
* Add field for edx-platform VerificationAttempt model id.
* Add event listener for user retirement signal.
* Update name of reverse accessor on User model to resolve conflict.
* Modify VerificationAttemptView to return inquiry_id.
* Make several fixes to the VerificationAttemptView view and the create_inquiry API method.
* Replace field `verified_name` with `name_first` when communicating with persona.
* Fix an error on the payload for create_inquiry API call to Persona.
* Sync updates to VerificationAttempt model.

2.0.0 - 2024-09-25
******************

Added
=====
* Bump version.

1.0.0 - 2024-07-18
******************

Added
=====

* Initial release.
* Setup repo using template.

0.1.0 - 2024-07-18
******************

Added
=====

* First release on PyPI.
